==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetAppServiceEnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service Environment.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetAppServiceEnvironmentPlainArgs(
    public val name: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs =
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAppServiceEnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetAppServiceEnvironmentPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service Environment.
     */
    @JvmName("wplhbkkvbaoponwa")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("txdxlxlbcyyouimj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAppServiceEnvironmentPlainArgs = GetAppServiceEnvironmentPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetAppServiceEnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service Environment.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetAppServiceEnvironmentPlainArgs(
    public val name: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs =
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAppServiceEnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetAppServiceEnvironmentPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service Environment.
     */
    @JvmName("gyejnaxnociqdwvf")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("rrqwfixhxjoicmyb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAppServiceEnvironmentPlainArgs = GetAppServiceEnvironmentPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
